/*******************************************************************
Copyright (c) 2002 The University of Maryland.

Permission is hereby granted, without written agreement and without
license or royalty fees, to use, copy, modify, and distribute this
software and its documentation for any purpose, provided that the above
copyright notice and the following two paragraphs appear in all copies
of this software.

IN NO EVENT SHALL THE UNIVERSITY OF MARYLAND BE LIABLE TO ANY PARTY
FOR DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES
ARISING OUT OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION, EVEN IF
THE UNIVERSITY OF MARYLAND HAS BEEN ADVISED OF THE POSSIBILITY OF
SUCH DAMAGE.

THE UNIVERSITY OF MARYLAND SPECIFICALLY DISCLAIMS ANY WARRANTIES,
INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE SOFTWARE
PROVIDED HEREUNDER IS ON AN "AS IS" BASIS, AND THE UNIVERSITY OF
MARYLAND HAS NO OBLIGATION TO PROVIDE MAINTENANCE, SUPPORT, UPDATES,
ENHANCEMENTS, OR MODIFICATIONS.
********************************************************************/

//////////////////////////////////////////////////////////////////////////
//// DPDemo
/**
A demo program for data partitioning and multirate cycle breaking
scheduler. The program takes input as an SDF graph and all potential
parallel memory operations. The parallelism is represented by a conflict
graph to which data partioning algorithms are applied.

@author Mingyung Ko
@version $Id$
*/

public class DPDemo {

    static public void main(String[] arguments) {
        String out = new String();

        String benchmarkName = arguments[0];

        // Get the conflict graph and SDF graph.
        PartitionedGraph conflictGraph =
                BenchmarkReader.conflictGraphReader(benchmarkName);
        SDFGraph sdfgraph = BenchmarkReader.getAssociatedSDFGraph();
        out += "Input graph:\n" + sdfgraph + "\n";

        // Multirate-cycle-breaking schedule computation.
        MultirateCycleBreaking scheduler =
                new MultirateCycleBreaking(sdfgraph);
        SDFSchedule schedule = (SDFSchedule)scheduler.result();
        out += "Result schedule:\n" + schedule + "\n\n";

        DataPartitioning algorithms =
                new DataPartitioning(conflictGraph);
        PartitionedGraph result;
        double colorCost, greedyCost;

        out += "Bank capacity requirement:\n";
        // 2-coloring strategy.
        out += "coloring = ";
        double color0, color1;
        result = algorithms.twoColoringStrategy();
        color0 = result.valueOf(
                (GraphPartition)result.getPartitions().get(0));
        color1 = result.valueOf(
                (GraphPartition)result.getPartitions().get(1));
        colorCost = Math.max(color0, color1);
        out += (int)colorCost + "\n";

        // My greedy strategy.
        out += "SPF = ";
        result = algorithms.greedyStrategy(2);
        double greedy0 = result.valueOf(
                (GraphPartition)result.getPartitions().get(0));
        double greedy1 = result.valueOf(
                (GraphPartition)result.getPartitions().get(1));
        greedyCost = Math.max(greedy0, greedy1);
        out += (int)greedyCost + "\n";

        // Compute improvement.
        double improve = (colorCost - greedyCost) / colorCost;
        out += "reduction = " + (improve * 100.0) + " %\n";

        System.out.println(out);
    }
}
