/* Partition of a graph.

 Copyright (c) 2002 The University of Maryland. All rights reserved.
 Permission is hereby granted, without written agreement and without
 license or royalty fees, to use, copy, modify, and distribute this
 software and its documentation for any purpose, provided that the above
 copyright notice and the following two paragraphs appear in all copies
 of this software.

 IN NO EVENT SHALL THE UNIVERSITY OF MARYLAND BE LIABLE TO ANY PARTY
 FOR DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES
 ARISING OUT OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION, EVEN IF
 THE UNIVERSITY OF MARYLAND HAS BEEN ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.

 THE UNIVERSITY OF MARYLAND SPECIFICALLY DISCLAIMS ANY WARRANTIES,
 INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE SOFTWARE
 PROVIDED HEREUNDER IS ON AN "AS IS" BASIS, AND THE UNIVERSITY OF
 MARYLAND HAS NO OBLIGATION TO PROVIDE MAINTENANCE, SUPPORT, UPDATES,
 ENHANCEMENTS, OR MODIFICATIONS.

*/

import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;

//////////////////////////////////////////////////////////////////////////
//// GraphPartition
/** A partition of a graph. A partition is itself a graph, too. Basically,
partitions are subgraphs with additional functions.

@author Mingyung Ko
@version $Id: GraphPartition.java,v 1.1 2002/12/24 22:19:48 keceli Exp $
*/

public class GraphPartition extends PartitionBase {

    /** A null constructor.
     */
    public GraphPartition() {}

    /** Constructor for a given graph. Construct the partition by
     *  duplicating all nodes and edges.
     *  @param graph The graph to construct from.
     */
    public GraphPartition(Graph graph) {
        addNodes(graph.nodes());
        addEdges(graph.edges());
    }

    ///////////////////////////////////////////////////////////////////
    ////                         public methods                    ////

    /** Get an ascendently sorted edges.
     *  @return The sorted edges in <code>List</code>.
     */
    public List ascendentEdges() {
        return ascendentListOf(edges());
    }

    /** Get an ascendently sorted nodes.
     *  @return The sorted nodes in <code>List</code>.
     */
    public List ascendentNodes() {
        return ascendentListOf(nodes());
    }


    /** Get common edges residing both in this partion and the argument
     *  graph. This is basically an intersection operation.
     *  @param theOtherGraph The other graph to get common edges.
     *  @return The common edges.
     */
/*
    public Collection commonEdgesOf(Graph theOtherGraph) {
        ArrayList commonEdges = new ArrayList();
        Iterator theOtherEdges = theOtherGraph.edges().iterator();
        while (theOtherEdges.hasNext()) {
            Edge theOtherEdge = (Edge)theOtherEdges.next();
            if (containsEdge(theOtherEdge))
                commonEdges.add(theOtherEdge);
        }
        return commonEdges;
    }
*/

    /** Get common nodes residing both in this partion and the argument
     *  graph. This is basically an intersection operation.
     *  @param theOtherGraph The other graph to get common nodes.
     *  @return The common nodes.
     */
/*
    public Collection commonNodesOf(Graph theOtherGraph) {
        ArrayList commonNodes = new ArrayList();
        Iterator theOtherNodes = theOtherGraph.nodes().iterator();
        while (theOtherNodes.hasNext()) {
            Node theOtherNode = (Node)theOtherNodes.next();
            if (containsNode(theOtherNode))
                commonNodes.add(theOtherNode);
        }
        return commonNodes;
    }
*/

    /** Get a descendently sorted edges.
     *  @return The sorted edges in <code>List</code>.
     */
    public List descendentEdges() {
        return descendentListOf(edges());
    }

    /** Get a descendently sorted nodes.
     *  @return The sorted nodes in <code>List</code>.
     */
    public List descendentNodes() {
        return descendentListOf(nodes());
    }

    ///////////////////////////////////////////////////////////////////
    ////                        private methods                    ////

    ///////////////////////////////////////////////////////////////////
    ////                       private variables                   ////
}
